@@ -11,7 +11,9 @@ from pytorch_grad_cam import GradCAM, \
     EigenCAM, \
     EigenGradCAM, \
     LayerCAM, \
-    FullGrad
+    FullGrad, \
+    GradCAMElementWise
+
 from pytorch_grad_cam import GuidedBackpropReLUModel
 from pytorch_grad_cam.utils.image import show_cam_on_image, \
     deprocess_image, \
@@ -71,7 +73,8 @@ if __name__ == '__main__':
          "eigencam": EigenCAM,
          "eigengradcam": EigenGradCAM,
          "layercam": LayerCAM,
-         "fullgrad": FullGrad}
+         "fullgrad": FullGrad,
+         "gradcamelementwise": GradCAMElementWise}
 
     model = models.resnet50(pretrained=True)
 
