@@ -1,4 +1,5 @@
 from pytorch_grad_cam.grad_cam import GradCAM
+from pytorch_grad_cam.grad_cam_elementwise import GradCAMElementWise
 from pytorch_grad_cam.ablation_layer import AblationLayer, AblationLayerVit, AblationLayerFasterRCNN
 from pytorch_grad_cam.ablation_cam import AblationCAM
 from pytorch_grad_cam.xgrad_cam import XGradCAM
@@ -7,8 +8,9 @@ from pytorch_grad_cam.score_cam import ScoreCAM
 from pytorch_grad_cam.layer_cam import LayerCAM
 from pytorch_grad_cam.eigen_cam import EigenCAM
 from pytorch_grad_cam.eigen_grad_cam import EigenGradCAM
+from pytorch_grad_cam.random_cam import RandomCAM
 from pytorch_grad_cam.fullgrad_cam import FullGrad
 from pytorch_grad_cam.guided_backprop import GuidedBackpropReLUModel
 from pytorch_grad_cam.activations_and_gradients import ActivationsAndGradients
 import pytorch_grad_cam.utils.model_targets
-import pytorch_grad_cam.utils.reshape_transforms
\ No newline at end of file
+import pytorch_grad_cam.utils.reshape_transforms
